<?php
/**
 * @package WordPress
 * @subpackage Loren
 */
 
 if ( ! function_exists( 'loren_setup' ) ) :

function loren_setup() {
	
	load_theme_textdomain('loren', get_theme_file_path('/languages') );
add_theme_support( 'automatic-feed-links' ); 
add_theme_support( 'title-tag' );
add_theme_support( 'post-formats', array( 'gallery', 'video', 'audio' ) );
	
	// Register Post Thumbnail
add_theme_support( 'post-thumbnails' );
set_post_thumbnail_size(1000,600,true);
add_image_size( 'loren-post-img', 1000, 600, true );
add_image_size( 'loren-post-img-small', 500, 300, true ); 

	register_nav_menus(
		array(
			'primary-menu' => esc_html__( 'Primary Menu', 'loren')
		)
	);
	
	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form',
		'comment-form',
		'comment-list',
		'gallery',
		'caption',
	) );	
	
	// Set up the WordPress core custom background feature
	add_theme_support( 'custom-background', apply_filters( 'loren_custom_background_args', array(
		'default-color' => 'EDEEF1',
		'default-image' => '',
	) ) );
	
	add_theme_support( 'appearance-tools' );
	
	// Add theme support for selective refresh for widgets
	add_theme_support( 'customize-selective-refresh-widgets' );
	
	// Add support for core custom logo
	add_theme_support( 'custom-logo', array(
		'height'      => 150,
		'width'       => 250,
		'flex-width'  => true,
		'flex-height' => true,
	) );
	
	// Add support for full and wide align images.
	add_theme_support( 'align-wide' );
	
	// Add support for Block Styles.
	add_theme_support( 'wp-block-styles' );
	
	// Add support for responsive embedded content.
	add_theme_support( 'responsive-embeds' );
	
	// Add support for custom header
	add_theme_support( 'custom-header', array(
	'width'         => 1920,
	'height'        => 1080,
	'default-image' => '',
	) );
	
	// Add support for editor styles.
	add_theme_support( 'editor-styles' );

	// Enqueue editor styles.
	add_editor_style( 'css/style-editor.css' );
	
}
endif;

add_action( 'after_setup_theme', 'loren_setup' );

function loren_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'loren_content_width', 1170 );
}
add_action( 'after_setup_theme', 'loren_content_width', 0 );

/* TGM Plugin Activation */
include_once ( get_theme_file_path('/include/tgm-plugin/plugin-install.php') );

//Add Google Web Fonts

if( !function_exists( 'loren_fonts_url' ) ) {

function loren_fonts_url() {
    $font_url = '';
	
	$mt_body_font = get_theme_mod( 'mt_body_font', 'Open Sans');
	$mt_body_font_weight = get_theme_mod( 'mt_body_font_weight', '300,400,600,700,800,300italic,400italic,700italic');
	$mt_post_titles_font = get_theme_mod( 'mt_post_titles_font', 'Karla');
	$mt_post_titles_font_weight = get_theme_mod( 'mt_post_titles_font_weight', '400,700,400italic,700italic');
    
    /*
    Translators: If there are characters in your language that are not supported
    by chosen font(s), translate this to 'off'. Do not translate into your own language.
     */
    if ( 'off' !== _x( 'on', 'Google font: on or off', 'loren' ) ) {
	
	if ( $mt_body_font != $mt_post_titles_font ){
	
	 $font_url = add_query_arg( 'family', urlencode( $mt_body_font.':'.$mt_body_font_weight.'|'.$mt_post_titles_font.':'.$mt_post_titles_font_weight.'&display=swap'), "//fonts.googleapis.com/css" );
	
	}
	
	else{ $font_url = add_query_arg( 'family', urlencode( $mt_body_font.':'.$mt_body_font_weight.'&display=swap'), "//fonts.googleapis.com/css" );
	}
		
    }
    return $font_url;
}

}

if( !function_exists( 'loren_fonts_script' ) ) {

function loren_fonts_script() {

    wp_enqueue_style( 'loren-fonts', loren_fonts_url(), array(), null );
	
}
add_action( 'wp_enqueue_scripts', 'loren_fonts_script' );

}

/**
* Enqueue editor styles for Gutenberg
*/
 
function loren_editor_styles() {
	wp_enqueue_style('font-awesome1', get_theme_file_uri('/css/fontawesome/css/all.min.css'), array(), null);
    wp_enqueue_style( 'loren-fonts', loren_fonts_url(), array(), null );
}
add_action( 'enqueue_block_editor_assets', 'loren_editor_styles' );


//	Register and load front end JS and CSS files
if( !function_exists( 'loren_scripts_init' ) ) {
    function loren_scripts_init() {
	
		wp_enqueue_style('bootstrap', get_theme_file_uri('/css/bootstrap/css/bootstrap.min.css'), array(), null);
		wp_enqueue_style('font-awesome1', get_theme_file_uri('/css/fontawesome/css/all.min.css'), array(), null);
		wp_enqueue_style('loren-style-css', get_parent_theme_file_uri('/style.css'), array(), null);
		
		wp_enqueue_script('easing', get_theme_file_uri('/js/jquery.easing.min.js'), array( 'jquery' ),null,true);
		wp_enqueue_script('slickslider', get_theme_file_uri('/js/slick.min.js'), array( 'jquery' ),null,true);
		wp_enqueue_script('simple-lightbox', get_theme_file_uri('/js/simple-lightbox.js'), array( 'jquery' ),null,true);
		wp_enqueue_script('loren-init', get_theme_file_uri('/js/init.js'), array( 'jquery' ),null,true);
		
    }
    
    add_action('wp_enqueue_scripts', 'loren_scripts_init');
}

function loren_comments_reply() {
	
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}

add_action( 'comment_form_before', 'loren_comments_reply' );

// Register Sidebars

function loren_widgets_init() {
	
	//main sidebar
	register_sidebar(array(
		'id' => 'sidebar-1',
		'name' => 'Sidebar',
		'description' => esc_html__( 'Main sidebar that appears on the right.','loren' ),
		'before_widget' => '<li id="%1$s" class="widget %2$s">',
		'after_widget' => '</li>',
		'before_title' => '<h5 class="widgettitle">',
		'after_title' => '</h5>'
	));
	
	//footer instagram
	register_sidebar(array(
		'name' => esc_html__( 'Footer Instagram','loren'),
		'id' => 'footer-instagram',
		'description' => esc_html__( 'We recommend to use only the Instagram widget here. Please check the documentation for more info.','loren' ),
		'before_widget' => '<div id="%1$s" class="widget-footer-instagram %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h5 class="widgettitle">',
		'after_title' => '</h5>'
	));
	
	//footer 1
	register_sidebar(array(
		'name' => esc_html__( 'Footer 1','loren'),
		'id' => 'footer-one',
		'description' => esc_html__( 'Widgets in this area are used in the first footer column','loren' ),
		'before_widget' => '<div id="%1$s" class="widget widget-footer %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h5 class="widgettitle">',
		'after_title' => '</h5>'
	));
	
	//footer 2
	register_sidebar(array(
		'name' => esc_html__( 'Footer 2','loren'),
		'id' => 'footer-two',
		'description' => esc_html__( 'Widgets in this area are used in the second footer column','loren' ),
		'before_widget' => '<div id="%1$s" class="widget widget-footer %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h5 class="widgettitle">',
		'after_title' => '</h5>'
	));
	
	//footer 3
	register_sidebar(array(
		'name' => esc_html__( 'Footer 3','loren'),
		'id' => 'footer-three',
		'description' => esc_html__( 'Widgets in this area are used in the third footer column','loren' ),
		'before_widget' => '<div id="%1$s" class="widget widget-footer %2$s">',
		'after_widget' => '</div>',
		'before_title' => '<h5 class="widgettitle">',
		'after_title' => '</h5>'
	));
	
}
add_action( 'widgets_init', 'loren_widgets_init' );

// Excerpt Content
function loren_excerpt_length( $length ) {
	return 60;
}
add_filter( 'excerpt_length', 'loren_excerpt_length');

function loren_excerpt_more( $more ) {
	return '...';
}
add_filter('excerpt_more', 'loren_excerpt_more');

//page navigation
function loren_pagenavi( $p = 2 ) { // pages will be show before and after current page
  if ( is_singular() ) return; // don't show in single page
  global $wp_query, $paged;
  $max_page = $wp_query->max_num_pages;
  
  if ( $max_page == 1 ) return; // don't show when only one page
  if ( empty( $paged ) ) $paged = 1;
  echo '<div class="prev-next">';
  echo '<span class="nav-page">';
  previous_posts_link(esc_html__('&larr; Newer', 'loren'));
  echo '</span>';
  if ( $paged > $p + 1 ) loren_p_link( 1 );
  if ( $paged > $p + 2 ) echo '<span class="more-pages">...</span>';
  for( $i = $paged - $p; $i <= $paged + $p; $i++ ) { // Middle pages
    if ( $i > 0 && $i <= $max_page ) $i == $paged ? print "<span class='page-numbers current-page'>{$i}</span> " : loren_p_link( $i );
  }
  if ( $paged < $max_page - $p - 1 ) echo '<span class="more-pages">...</span>';
  if ( $paged < $max_page - $p ) loren_p_link( $max_page );
  echo '<span class="nav-page">';
  next_posts_link(esc_html__('Older &rarr;', 'loren'));
  echo '</span>';
  echo '</div><!--end-->';
}
function loren_p_link( $i ) {
    echo "<a class='page-numbers' href='", esc_html( get_pagenum_link( $i ) ), "'>{$i}</a> ";
}

function loren_custom_comments($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment;
?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID() ?>">
		<div id="comment-<?php comment_ID(); ?>" class="comment-body <?php if ($comment->comment_approved == '0') echo 'pending-comment'; ?> clearfix">
                <div class="comment-details">
                    <div class="comment-avatar">
                        <?php echo get_avatar($comment, $size = '45'); ?>
                    </div><!-- /comment-avatar -->
                    
                    <div class="comment-right">
                    <section class="comment-author vcard">
					<ul class="comment-meta"> 
                    <li class="comm-author"><?php echo get_comment_author_link()?></li>
                    <li class="comm-date"> <?php echo get_comment_date(); ?></li>
                    <li class="comm-reply"><?php comment_reply_link(array_merge( $args, array('reply_text' => esc_html__('Reply','loren'),'depth' => $depth, 'max_depth' => $args['max_depth']))) ?></li>
                    </ul>
                    </section><!-- /comment-meta -->
                    <section class="comment-content">
    	                <div class="comment-text">
    	                    <?php comment_text() ?>
    	                </div><!-- /comment-text -->
    	               
                    </section><!-- /comment-content -->
                    
                   </div><!-- /comment-right -->
                    
				</div><!-- /comment-details -->
		</div><!-- /comment -->
<?php
}
function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328216&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        